Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(711)

Unified Diff: chrome/test/automation/automation_messages.h

Issue 4194007: Revert "Refactor automation messages." due to mysterious problems on mac. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 10 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/test/automation/automation_handle_tracker.cc ('k') | chrome/test/automation/automation_messages.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/test/automation/automation_messages.h
diff --git a/chrome/common/automation_messages.h b/chrome/test/automation/automation_messages.h
similarity index 95%
rename from chrome/common/automation_messages.h
rename to chrome/test/automation/automation_messages.h
index b4b22cde0b8de380fec608560004d2b63e132ce8..bb6d8669e0bdf6e67e72f22a642d645bcc6bc4d0 100644
--- a/chrome/common/automation_messages.h
+++ b/chrome/test/automation/automation_messages.h
@@ -2,20 +2,21 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_COMMON_AUTOMATION_MESSAGES_H__
-#define CHROME_COMMON_AUTOMATION_MESSAGES_H__
+#ifndef CHROME_TEST_AUTOMATION_AUTOMATION_MESSAGES_H__
+#define CHROME_TEST_AUTOMATION_AUTOMATION_MESSAGES_H__
#pragma once
#include <string>
#include "base/basictypes.h"
-#include "chrome/common/automation_constants.h"
+#include "chrome/browser/tab_contents/navigation_entry.h"
+#include "chrome/browser/tab_contents/security_style.h"
#include "chrome/common/common_param_traits.h"
-#include "chrome/common/page_type.h"
-#include "chrome/common/security_style.h"
+#include "chrome/test/automation/automation_constants.h"
#include "gfx/rect.h"
#include "net/base/upload_data.h"
+
struct AutomationMsg_Find_Params {
// Unused value, which exists only for backwards compat.
int unused;
@@ -198,8 +199,8 @@ struct ParamTraits<SecurityStyle> {
};
template <>
-struct ParamTraits<PageType> {
- typedef PageType param_type;
+struct ParamTraits<NavigationEntry::PageType> {
+ typedef NavigationEntry::PageType param_type;
static void Write(Message* m, const param_type& p) {
m->WriteInt(p);
}
@@ -207,19 +208,19 @@ struct ParamTraits<PageType> {
int type;
if (!m->ReadInt(iter, &type))
return false;
- *p = static_cast<PageType>(type);
+ *p = static_cast<NavigationEntry::PageType>(type);
return true;
}
static void Log(const param_type& p, std::string* l) {
std::string control;
switch (p) {
- case NORMAL_PAGE:
+ case NavigationEntry::NORMAL_PAGE:
control = "NORMAL_PAGE";
break;
- case ERROR_PAGE:
+ case NavigationEntry::ERROR_PAGE:
control = "ERROR_PAGE";
break;
- case INTERSTITIAL_PAGE:
+ case NavigationEntry::INTERSTITIAL_PAGE:
control = "INTERSTITIAL_PAGE";
break;
default:
@@ -519,7 +520,7 @@ struct ParamTraits<NavigationInfo> {
};
// A stripped down version of ContextMenuParams in webkit/glue/context_menu.h.
-struct MiniContextMenuParams {
+struct ContextMenuParams {
// The x coordinate for displaying the menu.
int screen_x;
@@ -547,10 +548,10 @@ struct MiniContextMenuParams {
GURL frame_url;
};
// Traits for MiniContextMenuParams structure to pack/unpack.
template <>
-struct ParamTraits<MiniContextMenuParams> {
- typedef MiniContextMenuParams param_type;
+struct ParamTraits<ContextMenuParams> {
+ typedef ContextMenuParams param_type;
static void Write(Message* m, const param_type& p) {
WriteParam(m, p.screen_x);
WriteParam(m, p.screen_y);
@@ -638,7 +639,7 @@ struct ParamTraits<AttachExternalTabParams> {
} // namespace IPC
#define MESSAGES_INTERNAL_FILE \
- "chrome/common/automation_messages_internal.h"
+ "chrome/test/automation/automation_messages_internal.h"
#include "ipc/ipc_message_macros.h"
-#endif // CHROME_COMMON_AUTOMATION_MESSAGES_H__
+#endif // CHROME_TEST_AUTOMATION_AUTOMATION_MESSAGES_H__
« no previous file with comments | « chrome/test/automation/automation_handle_tracker.cc ('k') | chrome/test/automation/automation_messages.cc » ('j') | no next file with comments »

Powered by Google App Engine
@@ -547,10 +548,10 @@ struct MiniContextMenuParams {
GURL frame_url;
};
-// Traits for MiniContextMenuParams structure to pack/unpack.
+// Traits for ContextMenuParams structure to pack/unpack.
template <>
This is Rietveld 408576698